/*
 *	Copyright: Torquil Gault (tag@scatha.apana.org.au), 1998+
 *
 */

package rpcs.system;

import com.sun.java.swing.*;
import java.awt.*;
import java.io.*;
import java.util.*;
import rpcs.event.*;

public class RPCSBaseSystem extends JPanel implements Serializable {
	String  rpcs_system;	/* using what System AD&D/MERP/RM etc */
	String  init_sys;	/* initiatives system */
	boolean use_logging;	/* using action logging */
	float   xp_mult; 	/* XP multiplier */
	String  pty_fn;		/* party load/save filename */
	String  mon_fn;		/* monster load/save filename */
	String  xta_fn;		/* extra's load/save filename */
	String  log_fn;		/* log load/save filename */
//	String  sys_dr;		/* system directory */
	int     rnd_no;		/* current round no */
	int     cur_init;	/* current init value */
	int     cur_atk;	/* current ID of attacker */
	int     cur_def;	/* current ID of defender */

	String  cur_crit;	/* current Critical type */
	int     atk_ptr;	/* current attack form, primary/sec crit */
	int     edit_pty;	/* have they edited the party */
	int     edit_mon;	/* have they edited the monsters */
	int     plyr_actn;	/* current ID of players action */
	boolean  roll_all;	/* roll all rolls */
	String  icon_detail;	/* Show Icon gif's */

	Color   PlyrColor;	/* Color of Player Buttons */
	Color   TrapColor;	/* Color of Trap Buttons */
	Color   MonstColor;	/* Color of Monster Buttons */

	String  GridType;	/* None, Hex, Sqr etc */
	float   GridDistance;	/* distance b/n grid squares */
	boolean GridSnap;

	RPCSParam Params;
	RPCSForm sForm;
	
	public RPCSBaseSystem(RPCSParam param) {
		Params = param;
		init();
	}

	public void init() {
		use_logging = false;
		roll_all = false;
		GridSnap = true;
		GridDistance = (float )5.0;
		xp_mult = (float )1.0;
		rnd_no = 1;

		PlyrColor = TrapColor = MonstColor = Color.lightGray;

		rpcs_system = new String("Ad&d");
		init_sys = new String("Std");
		pty_fn = new String("PtyFile.pty");
		mon_fn = new String("MonFile.mon");
		xta_fn = new String("XtaFile.xta");
		log_fn = new String("LogFile.log");
		cur_crit = new String("");
		GridType = new String("Hex");
		icon_detail = new String("Low");

		sForm = new RPCSForm(this, true);
		{
		  String[] ts = {"Hex", "Sqr", "None"};
		  sForm.add("Grid Type", ts, GridType);
		}
		sForm.newColumn("Grid Type");
		sForm.add("Grid Distance", GridDistance);
		sForm.newColumn("Grid Distance");
		sForm.add("Snap to Grid", GridSnap);
		sForm.newBlankRow("Grid Type");
		sForm.add("Use Logging", use_logging);
		sForm.newBlankRow("Use Logging");
		{
		  String[] ts = {"AD&D", "MERP", "RMSS"};
		  sForm.add("System Used", ts, rpcs_system);
		}
		{
		  String[] ts = {"Std", "Init-1", "Init-2"};
		  sForm.add("Init System", ts, init_sys);
		}
		sForm.add("XP Multiplier", xp_mult);
		sForm.newBlankRow("XP Multiplier");
		sForm.add("Party File", pty_fn);
		sForm.add("Monster File", mon_fn);
		sForm.newColumn("Party File");
		sForm.add("Extra File", xta_fn);
		sForm.add("Log File", log_fn);
		sForm.newBlankRow("Monster File");
		sForm.add("Round No", rnd_no);
		sForm.add("Roll all Rolls", roll_all);
		sForm.newBlankRow("Roll all Rolls");
		{
		  String[] ts = {"Black", "Blue", "Cyan", "Grey", "Green", 
			"Magenta", "Orange", "Red", "White", "Yellow"};
		  sForm.add("Player Color", ts, "Grey");
		  sForm.newColumn("Player Color");
		  sForm.add("Trap Color", ts, "Grey");
		  sForm.newColumn("Trap Color");
		  sForm.add("Monster Color", ts, "Grey");
		}
		sForm.newBlankRow("Player Color");
		{
		  String[] ts = {"High", "Low"};
		  sForm.add("Icon Detail", ts, icon_detail);
		}

		sForm.addFormListener(new FormAdapter() {
		   public void okClicked() {
			doOK();
		   }
		   public void cancelClicked() {
			doCancel();
		   }
		   public void resetClicked() {
			doReset();
		   }
		});
	}

	public void doOK() {
// System.out.println("OK Pressed");
		Vector v = sForm.vTitle;
		for (int i=v.size()-1; i>=0; i--) {
		   System.out.println((String )v.elementAt(i) + "=" +
		  	   sForm.getFieldValue((String )v.elementAt(i)));
		}
	}

	public void doCancel() {
// System.out.println("Cancel Pressed");
	}

	public void doReset() {
// System.out.println("Reset Pressed");
	}

	public void nextRnd() {
		rnd_no++;
	}
}
